@@ -25,7 +25,7 @@ Usage::
     list_datastores_paginator: ListDatastoresPaginator = client.get_paginator("list_datastores")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
 """
-from mypy_boto3_iotanalytics.client import IoTAnalyticsClient as Client, IoTAnalyticsClient
+from mypy_boto3_iotanalytics.client import IoTAnalyticsClient, IoTAnalyticsClient as Client
 from mypy_boto3_iotanalytics.paginator import (
     ListChannelsPaginator,
     ListDatasetContentsPaginator,
